From b8066695797c32c9943113364ea45f1412c8931d Mon Sep 17 00:00:00 2001
From: Zachary Kanfer <zkanfer@gmail.com>
Date: Sat, 25 Jun 2022 01:48:38 -0400
Subject: [PATCH] Add a function to rename the file visited by the current
 buffer.

* lisp/files.el (rename-visited-file)
---
 etc/NEWS      |  4 ++++
 lisp/files.el | 20 ++++++++++++++++++++
 2 files changed, 24 insertions(+)

diff --git a/etc/NEWS b/etc/NEWS
index 6c04ae164c..1847cfcd77 100644
--- a/etc/NEWS
+++ b/etc/NEWS
@@ -339,6 +339,10 @@ match those regexps will be ignored by 'switch-to-prev-buffer' and
 
 ** Menus
 
+** New command 'rename-visited-file'.
+This command renames the file visited by the current buffer by moving
+it to a new location.
+
 ---
 *** The entries following the buffers in the "Buffers" menu can now be altered.
 Change the 'menu-bar-buffers-menu-command-entries' variable to alter
diff --git a/lisp/files.el b/lisp/files.el
index a804f0088e..856c6e9b8e 100644
--- a/lisp/files.el
+++ b/lisp/files.el
@@ -4817,6 +4817,26 @@ write-file
     ;; It's likely that the VC status at the new location is different from
     ;; the one at the old location.
     (vc-refresh-state)))
+
+(defun rename-visited-file (new-location)
+  "Rename the file visited by the current buffer to NEW-LOCATION.
+
+Interactively, this prompts for NEW-LOCATION.
+
+If the file has not been visited, this writes the file to NEW-LOCATION."
+  (interactive (list (if buffer-file-name
+                         (read-file-name "Rename file to: ")
+                       (read-file-name "Rename file to: "
+                                       default-directory
+                                       (expand-file-name (file-name-nondirectory (buffer-name))
+                                                         default-directory)))))
+  (let ((old-location (buffer-file-name)))
+    (write-file new-location t)
+    (when (and old-location
+               (file-exists-p old-location)
+               (file-exists-p new-location))
+      (delete-file old-location))))
+
 
 (defun file-extended-attributes (filename)
   "Return an alist of extended attributes of file FILENAME.
-- 
2.25.1

